@@ -11,6 +11,7 @@ class DjangoCronJobLock(object):
     except DjangoCronJobLock.LockFailedException:
         pass
     """
+
     class LockFailedException(Exception):
         pass
 
@@ -18,7 +19,7 @@ class DjangoCronJobLock(object):
         """
         This method inits the class.
         You should take care of getting all
-        nessesary thing from input parameters here
+        necessary thing from input parameters here
         Base class processes
             * self.job_name
             * self.job_code
@@ -26,7 +27,7 @@ class DjangoCronJobLock(object):
             * self.silent
         for you. The rest is backend-specific.
         """
-        self.job_name = cron_class.__name__
+        self.job_name = '.'.join([cron_class.__module__, cron_class.__name__])
         self.job_code = cron_class.code
         self.parallel = getattr(cron_class, 'ALLOW_PARALLEL_RUNS', False)
         self.silent = silent
@@ -39,7 +40,9 @@ class DjangoCronJobLock(object):
         False if fail.
         Here you can optionally call self.notice_lock_failed().
         """
-        raise NotImplementedError('You have to implement lock(self) method for your class')
+        raise NotImplementedError(
+            'You have to implement lock(self) method for your class'
+        )
 
     def release(self):
         """
@@ -47,17 +50,16 @@ class DjangoCronJobLock(object):
         Tipically called from __exit__ method.
         No need to return anything currently.
         """
-        raise NotImplementedError('You have to implement release(self) method for your class')
+        raise NotImplementedError(
+            'You have to implement release(self) method for your class'
+        )
 
     def lock_failed_message(self):
         return "%s: lock found. Will try later." % self.job_name
 
     def __enter__(self):
-        if self.parallel:
-            return
-        else:
-            if not self.lock():
-                raise self.LockFailedException(self.lock_failed_message())
+        if not self.parallel and not self.lock():
+            raise self.LockFailedException(self.lock_failed_message())
 
     def __exit__(self, type, value, traceback):
         if not self.parallel:
